==> aliyun-python-sdk-arms-2.5.9.tar.gz: aliyun-python-sdk-arms-2.5.9/aliyunsdkarms/request/v20190808/CreateRetcodeAppRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkarms.endpoint import endpoint_data

class CreateRetcodeAppRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'CreateRetcodeApp','arms')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_RetcodeAppName(self):
		return self.get_query_params().get('RetcodeAppName')

	def set_RetcodeAppName(self,RetcodeAppName):
		self.add_query_param('RetcodeAppName',RetcodeAppName)

	def get_RetcodeAppType(self):
		return self.get_query_params().get('RetcodeAppType')

	def set_RetcodeAppType(self,RetcodeAppType):
		self.add_query_param('RetcodeAppType',RetcodeAppType)

==> aliyun-python-sdk-arms-2.7.24.tar.gz: aliyun-python-sdk-arms-2.7.24/aliyunsdkarms/request/v20190808/CreateRetcodeAppRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkarms.endpoint import endpoint_data

class CreateRetcodeAppRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'ARMS', '2019-08-08', 'CreateRetcodeApp','arms')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_RetcodeAppName(self): # String
		return self.get_query_params().get('RetcodeAppName')

	def set_RetcodeAppName(self, RetcodeAppName):  # String
		self.add_query_param('RetcodeAppName', RetcodeAppName)
	def get_RetcodeAppType(self): # String
		return self.get_query_params().get('RetcodeAppType')

	def set_RetcodeAppType(self, RetcodeAppType):  # String
		self.add_query_param('RetcodeAppType', RetcodeAppType)
